@@ -7,7 +7,7 @@ import secrets
 import platform
 import sys
 
-from PySide2 import QtCore, QtTest, QtWidgets
+from PySide6 import QtCore, QtTest, QtWidgets
 
 from onionshare_cli.common import Common
 
@@ -58,6 +58,13 @@ class GuiBaseTest(unittest.TestCase):
                 "<html><body><p>This is a test website hosted by OnionShare</p></body></html>"
             )
 
+        # A file called "test.html"
+        cls.tmpfile_test_html = os.path.join(cls.tmpdir.name, "test.html")
+        with open(cls.tmpfile_test_html, "w") as file:
+            file.write(
+                "<html><body><p>Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis et quasi architecto beatae vitae dicta sunt explicabo. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt. Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem. Ut enim ad minima veniam, quis nostrum exercitationem ullam corporis suscipit laboriosam, nisi ut aliquid ex ea commodi consequatur? Quis autem vel eum iure reprehenderit qui in ea voluptate velit esse quam nihil molestiae consequatur, vel illum qui dolorem eum fugiat quo voluptas nulla pariatur?</p></body></html>"
+            )
+
         # A large file
         size = 1024 * 1024 * 155
         cls.tmpfile_large = os.path.join(cls.tmpdir.name, "large_file")
